Introduction
============

This packages contains a set of customisations of the `Euphorie
<http://euphorie.readthedocs.org/en/latest/>`_ risk assessment tool as
needed for the `Dutch RI&E <http://instrumenten.rie.nl/>`_ site:

* The company data collected and printed during the report phase is extended
  with numerous extra fields.

* ``tno.euphorie`` extends the online client to allow importing of survey
  sessions as generated by the old version of the *instrumenten.rie.nl* site as
  used up to September 2010. This can be done via a new form that is reachable
  from the country/session start page.


Contents
========

.. toctree::
   :maxdepth: 2

   installation
   api
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

